/* gtktempfilewavebuffer.h: class that stores data in a tempfile
 * Copyright (c) 2000 David A. Bartold
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_TEMPFILE_WAVE_BUFFER_H__
#define __GTK_TEMPFILE_WAVE_BUFFER_H__

#include <stdio.h>
#include <gdk/gdk.h>
#include "gtkwavebuffer.h"
#include "gtkeditablewavebuffer.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GTK_TYPE_TEMPFILE_WAVE_BUFFER            (gtk_tempfile_wave_buffer_get_type ())
#define GTK_TEMPFILE_WAVE_BUFFER(obj)            (GTK_CHECK_CAST ((obj), GTK_TYPE_TEMPFILE_WAVE_BUFFER, GtkTempfileWaveBuffer))
#define GTK_TEMPFILE_WAVE_BUFFER_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_TEMPFILE_WAVE_BUFFER, GtkTempfileWaveBufferClass))
#define GTK_IS_TEMPFILE_WAVE_BUFFER(obj)         (GTK_CHECK_TYPE ((obj), GTK_TYPE_TEMPFILE_WAVE_BUFFER))
#define GTK_IS_TEMPFILE_WAVE_BUFFER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_TEMPFILE_WAVE_BUFFER))


typedef struct _GtkTempfileWaveBuffer      GtkTempfileWaveBuffer;
typedef struct _GtkTempfileWaveBufferClass GtkTempfileWaveBufferClass;


struct _GtkTempfileWaveBuffer
{
  GtkEditableWaveBuffer object;

  FILE          *file;
  guint16        n_channels;
  GWavefileType  d_type;
  guint32        rate;
  guint32        length;
  GMutex        *in_use;
};

struct _GtkTempfileWaveBufferClass
{
  GtkEditableWaveBufferClass object_class;
};


GtkType    gtk_tempfile_wave_buffer_get_type (void);
GtkObject *gtk_tempfile_wave_buffer_new      (guint16       n_channels,
                                              GWavefileType d_type,
                                              guint32       rate);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GTK_TEMPFILE_WAVE_BUFFER_H__ */

